# CHANGELOG

<!-- version list -->

## v0.2.0 (2026-03-06)

### Chores

- Add constraint on uv version
  ([`45b2f6d`](https://github.com/LinkupPlatform/langchain-linkup/commit/45b2f6df35213e93047d589a14157e5719febcd0))

- Setup semantic release
  ([`85497da`](https://github.com/LinkupPlatform/langchain-linkup/commit/85497daa47874a29193a9b04398f5bee006bdded))

- Update supported python versions
  ([`4877752`](https://github.com/LinkupPlatform/langchain-linkup/commit/48777521e0d5449b2c876a8804c1533e5b20e5bb))

- Update uv deps
  ([`d6920e2`](https://github.com/LinkupPlatform/langchain-linkup/commit/d6920e2cc7f4ec1cdbed074ab2dfa51c75a62b5d))

### Features

- Support latest SDK parameters
  ([`9f7ca0d`](https://github.com/LinkupPlatform/langchain-linkup/commit/9f7ca0d88745af94e9c8f77984328ac713ddd0f1))
